# ******************************************************
# *
# * Name:         make-server-n-database.ps1
# *     
# * Design Phase:
# *     Author:   John Miner
# *     Date:     11-29-2017
# *     Purpose:  Create azure sql server & database 
# *               using resource manager.
# * 
# ******************************************************


#
# Azure Subscriptions 
#

# Prompts you for azure credentials
Add-AzureRmAccount

# Clear the screen
Clear-Host

# List my subscriptions
Get-AzureRmSubscription

# Pick my MSDN one
Set-AzureRmContext -SubscriptionId 'cdfb69bf-3533-4c89-9684-1ba6ba81b226'



#
# Data Centers with my service
#

# Clear the screen
Clear-Host

# Data centers with Azure SQL database
$AzureSQLLocations = (Get-AzureRmResourceProvider -ListAvailable | Where-Object {$_.ProviderNamespace -eq 'Microsoft.Sql'}).Locations
$AzureSQLLocations



#
# Create a resource group
#

# New resource group
New-AzureRmResourceGroup -Name "rg4tips17" -Location "East US"

# Clear the screen
Clear-Host

# List resource groups
Get-AzureRmResourceGroup

# Delete resource group
# Remove-AzureRmResourceGroup -Name "rg4tips17" -Force



#
# Create a new server
#

# Create a credential
$User = "jminer"
$Pword = ConvertTo-SecureString String 'MS#tips$2017' AsPlainText -Force
$Credential = New-Object TypeName System.Management.Automation.PSCredential ArgumentList $User, $Pword

# New sql server
New-AzureRmSqlServer -ResourceGroupName "rg4tips17" -ServerName "mssqltips17" -Location "East US" -ServerVersion "12.0" -SqlAdministratorCredentials $Credential

# Clear the screen
Clear-Host

# List Sql Servers
Get-AzureRmSqlServer -ResourceGroupName "rg4tips17"

# Remove the sql server
#Remove-AzureRmSqlServer -ResourceGroupName "rg4tips17" -ServerName "mssqltips17" 



#
# Add laptop ip to firewall (todo = code to figure out ip since I am behind a router)
#

# Create new firewall rule
New-AzureRmSqlServerFirewallRule -ResourceGroupName "rg4tips17" -ServerName "mssqltips17" -FirewallRuleName "fr4laptop" -StartIpAddress "100.10.71.147" -EndIpAddress "100.10.71.147"

# Clear the screen
Clear-Host

# List firewall rules
Get-AzureRmSqlServerFirewallRule -ResourceGroupName "rg4tips17" -ServerName "mssqltips17"


# Remove firewall rule
# Remove-AzureRmSqlServerFirewallRule -ResourceGroupName "rg4tips17" -ServerName "mssqltips17" -FirewallRuleName "fr4laptop"



#
# Make the new database
#

# Create a new database
New-AzureRmSqlDatabase -ResourceGroupName "rg4tips17" -ServerName "mssqltips17" -DatabaseName "hippa" -Edition Standard -RequestedServiceObjectiveName S0

# Clear the screen
Clear-Host

# List the new database
Get-AzureRmSqlDatabase -ResourceGroupName "rg4tips17" -ServerName "mssqltips17"


# Remove the database
# Remove-AzureRmSqlDatabase -ResourceGroupName "rg4tips17" -ServerName "mssqltips17" -DatabaseName "hippa"






